package com.malk.dongfangxinhua.controller;

/**
 * 错误抛出与拦截详见 CatchException
 */

import cn.hutool.core.util.XmlUtil;
import cn.hutool.http.HttpRequest;
import cn.hutool.json.JSONArray;
import cn.hutool.json.JSONObject;
import cn.hutool.json.XML;
import com.alibaba.fastjson.JSON;
import com.malk.dongfangxinhua.service.PayService;
import com.malk.server.aliwork.YDConf;
import com.malk.server.aliwork.YDParam;
import com.malk.server.common.McException;
import com.malk.server.common.McR;
import com.malk.service.aliwork.YDClient;
import com.malk.utils.UtilHttp;
import com.malk.utils.UtilMap;
import com.malk.utils.UtilServlet;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.nio.charset.StandardCharsets;
import java.sql.ResultSet;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Random;
import java.util.stream.Collectors;

@Slf4j
@RestController
@RequestMapping
public class DFXHController {

    /// doc: http://47.111.179.216/interface/main.html#
    private static final String API = "http://27.115.15.66:8098/BisOutWeb/payCenter/dealReq.srv";




    @Autowired
    private YDClient ydClient;

    @Autowired
    private PayService payService;

    // xml请求
    private JSONObject _doPost(String tradeCode, Map condition) {

        // xml请求格式数据处理
        Map head = UtilMap.map("erpSysCode, custNo, tradeName", "XYYGLXT", "300200632", tradeCode);
        Map body = UtilMap.map("head, map", head, condition);
        String data = XmlUtil.mapToXmlStr(body, "body");
        log.info("请求入参, {}", XML.toJSONObject(data));

        /// prd 财资固定格式, xml头数据前需要添加类型code, 且不能换行
        data = "0000012001" + tradeCode + data;
        String rsp = HttpRequest.post(API).body(data).execute().body();
        JSONObject result = XML.toJSONObject(rsp);
        log.info("请求响应, {}", result);
        result = result.getJSONObject("body");

        // 错误拦截, 统一返回
        String message = result.getJSONObject("head").getStr("retMsg");
        McException.assertAccessException(!"查询成功".equals(message), message);

        return result;
    }

    /**
     * 查询联行号
     */
    @PostMapping("bank")
    McR bank(String name) {
        JSONObject rsp = _doPost("BY0004", UtilMap.map("bankName, isPreciseQuery", name, 0));
        JSONArray list = rsp.getJSONObject("loopData").getJSONArray("row");
        return McR.success(list);
    }


    /**
     * 发起付款申请
     */
    @PostMapping("payment")
    McR payment(@RequestBody Map data) {
        payService.payMent(data);
        return McR.success();
    }

    /**
     * 手工付款
     */
    @PostMapping("handWorkPayment")
    McR handWorkPayment(@RequestBody Map data) {
        payService.handWorkPayment(data);
        return McR.success();
    }


    /**
     * 付款状态
     */
    @PostMapping("state")
    McR payment(String payNo) {
        JSONObject rsp = _doPost("BY0003", UtilMap.map("erpReqNo", payNo));
        JSONObject state = rsp.getJSONObject("loopData").getJSONObject("row");
        return McR.success(state);
    }


    /**
     * 付款银行信息同步
     */
    @PostMapping("sync")
    @SneakyThrows
    McR sync(HttpServletRequest request) {
        Thread.sleep(2000);
        Map data = UtilServlet.getParamMap(request);
        log.info("付款银行信息同步, {}", data);
        payService.syncPayBankInfo(data);
        return McR.success();
    }

    /**
     * 付款状态同步
     */
    @PostMapping("syncPay")
    McR syncPay(HttpServletRequest request) {

        Map data = UtilServlet.getParamMap(request);
        log.info("付款状态同步, {}", data);
        payService.syncPayStatus();
        return McR.success();
    }


    /**
     *同步凭证
     * @param request
     * @return
     */
    @PostMapping("syncErp")
    McR pushErp(HttpServletRequest request) {

        // 查询付款申请单（获取跟付款申请表，查询状态为付款完成、凭证号为空的数据）
        YDParam ydParam = YDParam.builder()
                .formUuid("FORM-6L966171YHZA0OJOAUKWG89JTZA635EV3Y1ILR")
                .searchFieldJson(JSON.toJSONString(UtilMap.map("textField_lr08rrpc, textField_lof4wiqr", "付款成功","")))   //付款成功  且无凭证号的数据
                .build();

        //获取所有 状态为付款完成、凭证号为空的数据
        List<Map> dataList = (List<Map>) ydClient.queryData(ydParam, YDConf.FORM_QUERY.retrieve_search_form).getData();
        log.info("同步Erp凭证数据, {}", dataList);
        dataList.forEach(item ->{
            payService.synProofStatus((String) item.get("formInstanceId"));
        });

        return McR.success();
    }



    @PostMapping(value = "test")
    McR test(String name, HttpServletRequest request) {
        return McR.success();
    }


}
